package
{
	import Entities.Bullet;
	import Entities.Ship;
	import flash.display.Bitmap;
	import flash.display.BitmapData;
	import flash.display.MovieClip;
	import flash.display.Stage;
	import flash.events.Event;
	import flash.events.KeyboardEvent;
	
	import flash.utils.getTimer;

	public class Game
	{
		public var stage:Stage;
		public var ship:Ship;
		
		private const LEFT:int = 37;
		private const UP:int = 38;
		private const RIGHT:int = 39;
		private const SPACE:int = 32;	
		private const DOWN:int = 40;
		
		public static var stageWidth:int;
		public static var stageHeight:int;
		
		public static var current_time:Number; //used to track the time of the current frame
		private var bullets:Array; //used to hold all the bullets
		private var firing_delay:Number; //the delay before creating a new bullet when the space bar is held down
		private var last_fired:Number; //the time the last bullet was created
		private var bullets_max_life:Number; //the max life of the bullets
		private var space_down:Boolean; //Either set to true if the spacebar is being held down, or false if released
		
		public function Game(stage:Stage)
		{
			this.stage = stage;
			stageHeight = stage.stageHeight;
			stageWidth = stage.stageWidth;
			trace("Game created");
			
			//create the ship
			ship = new Ship(stage.stageWidth / 2 - 5, stage.stageHeight / 2 - 10);
			stage.addChild(ship);
			
			//now for input
			stage.addEventListener(KeyboardEvent.KEY_DOWN, KeyDown);
			stage.addEventListener(KeyboardEvent.KEY_UP, KeyUp);	
			
			bullets = new Array();
			firing_delay = 200;
			last_fired = 0;
			bullets_max_life = 1000;
			space_down = false;
		}
		public function Update(e:Event):void
		{
			current_time = getTimer();
			
			ship.Update();
			
			if (space_down && current_time-last_fired > firing_delay)
			{
				var angle_rad:Number = ship.rotation * Math.PI / 180;
				bullets.push(new Bullet(ship.x, ship.y, current_time, angle_rad));
				last_fired = current_time;
				stage.addChild(bullets[bullets.length - 1]);
			}
			
			var bullets_length:int = bullets.length - 1;
			for (var i:int = bullets_length; i > -1;i-- )
			{
				bullets[i].Update();
				if (current_time-bullets[i].life > bullets_max_life)
				{
					stage.removeChild(bullets[i]);
					bullets.splice(i, 1);
				}
			}
		}
		public function KeyDown(e:KeyboardEvent):void
		{
			if(e.keyCode==RIGHT)
				ship.rotation_amount = 15;				
			if(e.keyCode==LEFT)
				ship.rotation_amount = -15;
			if(e.keyCode==UP)
				ship.thrust = 1;
			if(e.keyCode==DOWN)
				ship.thrust = -1;
			if(e.keyCode==SPACE)
				space_down = true;	
		}
		public function KeyUp(e:KeyboardEvent):void
		{
			if(e.keyCode==RIGHT||e.keyCode==LEFT)
				ship.rotation_amount = 0;				
				
			if(e.keyCode==UP||e.keyCode==DOWN)
				ship.thrust = 0;	
			if(e.keyCode==SPACE)
				space_down = false;
		}
	}
}